# Overview
SCRUB is an orchestration and aggregation platform for static code analysis tools.

SCRUB allows users to run multiple static code analysis tools, collect the results, and export them to external tools.
The results from each analyzer are post-processed to a standard warning format that provides information about the
location of the warning as well as a brief description of the warning. These warnings can then reviewed and assessed by
experienced developers to determine their merit.

A full description of the origins of SCRUB, written by the original author (Gerard Holzmann), can be [found here](http://spinroot.com/gerard/pdf/ScrubPaper_rev.pdf).

## Table of Contents

* [Installation](installation.md)
* [Usage](usage.md)
* [Configuration](configuration.md)
* [FAQ](faq.md)
* [Filtering](filtering.md)
* [Output](output.md)
* [Reviewing Results](reviewing.md)
* [Troubleshooting](troubleshooting.md)
* [Utilities](utilities.md)
* [Authors](authors.md)

